// Author: Olivier Loisel (CREST). Date: June 2020.
// This Dynare file is called by the Matlab file ISP_Fig1_check.m, which checks Figure 1 and the Supplementary Appendix S.1 in the paper "The Implementation of Stabilization Policy" (O. Loisel, June 2020).
// It is consistent at least with version 4.3.0 of Dynare.
// It computes the impulse-response functions to the two exogenous shocks on the optimal feasible path, using the ramsey_policy command of Dynare.
// The names of the parameters correspond to their notations in the paper (with the suffix "_ra" standing for "ramsey").

var pi, y, i, aux, eta, u; 
varexo epseta, epsu;
parameters beta_ra, sigma_ra, kappa_ra, lambda_ra, rho_eta_ra, rho_u_ra, theta_u_ra, theta_eta_ra;

load('Param.mat');
beta_ra = beta;
sigma_ra = sigma;
kappa_ra = kappa;
lambda_ra = lambda;
rho_eta_ra = rho_eta;
rho_u_ra = rho_u;
theta_u_ra = theta_u;
theta_eta_ra = theta_eta;

model (linear);
i = aux(-1);
y=y(+1)-1/sigma_ra*(aux(-1)-pi(+1))+eta;
pi=beta_ra*pi(+1)+kappa_ra*y +u;
eta = rho_eta_ra*eta(-1) + epseta + theta_eta_ra*epseta(-1);
u = rho_u_ra*u(-1) + epsu + theta_u_ra*epsu(-1);
end;

shocks;
var epseta = 1;
var epsu = 1;
corr epseta, epsu = 0;
end;

planner_objective pi^2 + lambda_ra*y^2;
ramsey_policy(planner_discount=beta_ra,irf=20,order=1,nograph,noprint);