// Author: Olivier Loisel (CREST). Date: June 2020.
// This Dynare file is called by the Matlab file ISP_Fig1_check.m, which checks Figure 1 and the Supplementary Appendix S.1 in the paper "The Implementation of Stabilization Policy" (O. Loisel, June 2020).
// It is consistent at least with version 4.3.0 of Dynare.
// This file determines whether Blanchard and Kahn's (1980) root-counting and no-decoupling conditions are met under the rule (32).
// When there are met, it computes the impulse-reponse functions to the two exogenous shocks.
// The names of the parameters that appear also in the paper correspond to their notations in the paper (with the suffix "_ru" standing for "rule").

var pi, y, i, eta, u; 
varexo epseta, epsu; 
parameters beta_ru, sigma_ru, kappa_ru, lambda_ru, rho_eta_ru, rho_u_ru, theta_u_ru, theta_eta_ru, pi1, pi2, pi3, pi4, pi5, pi6, pi7, y1, y2, y3, y4, y5, y6, y7, i0, i1, i2, i3,
i4, i5, i6, i7;

load('Param.mat');
beta_ru = beta;
sigma_ru = sigma;
kappa_ru = kappa;
lambda_ru = lambda;
rho_eta_ru = rho_eta;
rho_u_ru = rho_u;
theta_u_ru = theta_u;
theta_eta_ru = theta_eta;

load('ISP_Fig1_check.mat');
pi1 = F_pi_ext(7);
pi2 = F_pi_ext(6);
pi3 = F_pi_ext(5);
pi4 = F_pi_ext(4);
pi5 = F_pi_ext(3);
pi6 = F_pi_ext(2);
pi7 = F_pi_ext(1);
y1 = F_y_ext(7);
y2 = F_y_ext(6);
y3 = F_y_ext(5);
y4 = F_y_ext(4);
y5 = F_y_ext(3);
y6 = F_y_ext(2);
y7 = F_y_ext(1);
i0 = G_ext(8);
i1 = G_ext(7);
i2 = G_ext(6);
i3 = G_ext(5);
i4 = G_ext(4);
i5 = G_ext(3);
i6 = G_ext(2);
i7 = G_ext(1);

model (linear);
y = y(+1)-1/sigma_ru*(i-pi(+1))+eta;
pi = beta_ru*pi(+1)+kappa_ru*y +u;
i0*i+ i1*i(-1) + i2*i(-2) + i3*i(-3) + i4*i(-4) + i5*i(-5) + i6*i(-6) + i7*i(-7) =
pi1*pi(-1) + pi2*pi(-2) + pi3*pi(-3) + pi4*pi(-4) + pi5*pi(-5) + pi6*pi(-6) + pi7*pi(-7)
+ y1*y(-1) + y2*y(-2) + y3*y(-3) + y4*y(-4) + y5*y(-5) + y6*y(-6) + y7*y(-7);
eta = rho_eta_ru*eta(-1) + epseta + theta_eta_ru*epseta(-1);
u = rho_u_ru*u(-1) + epsu + theta_u_ru*epsu(-1);
end;

shocks;
var epseta = 1;
var epsu = 1;
corr epseta, epsu = 0;
end;

options_.noprint = 1;
check;

stoch_simul(irf=20,order=1,noprint,nograph);
error = info(1);