// Author: Olivier Loisel (CREST). Date: June 2020.
// This Dynare file is called by the Matlab file ISP_Fig2_check.m, which checks Figure 2 and the Supplementary Appendix S.2 in the paper "The Implementation of Stabilization Policy" (O. Loisel, June 2020).
// It is consistent at least with version 4.3.0 of Dynare.
// It computes the impulse-response functions to the two exogenous shocks on the optimal feasible path, using the ramsey_policy command of Dynare.
// The names of the parameters correspond to their notations in the paper (with the suffix "_ra" standing for "ramsey").
// The variables of type Xtilde (where X is pi, y, or i) correspond to E_t[X_{t+1}].

var pi, y, i, pitilde, ytilde, itilde, eta, u; 
varexo epseta, epsu;
parameters beta_ra, sigma_ra, kappa_ra, lambda_ra, rho_eta_ra, rho_u_ra;

load('Param.mat');
beta_ra = beta;
sigma_ra = sigma;
kappa_ra = kappa;
lambda_ra = lambda;
rho_eta_ra = rho_eta;
rho_u_ra = rho_u;

model (linear);
pi = pitilde(-1)+epsu;
y = ytilde(-1)+epseta;
i = itilde(-1);
pitilde = beta_ra*pitilde(+1)+kappa_ra*ytilde+rho_u_ra*u;
ytilde = ytilde(+1)-1/sigma_ra*(itilde-pitilde(+1))+rho_eta_ra*eta;
eta = rho_eta_ra*eta(-1) + epseta;
u = rho_u_ra*u(-1) + epsu;
end;

shocks;
var epseta = 1;
var epsu = 1;
corr epseta, epsu = 0;
end;

planner_objective pi^2 + lambda_ra*y^2;
ramsey_policy(planner_discount=beta_ra,irf=20,order=1,nograph,noprint);